@@ -1,6 +1,6 @@
 import prefect
-import datamonk.utils as utils
-
+from datamonk.utils import functions as utils
+from datamonk.scriptorium.process import monitoring
 import datamonk.scriptorium.apps.dataform as dataform
 import os
 
@@ -15,11 +15,10 @@ def dataform_transform(project_id=os.environ.get("DATAFORM_PROJECT_ID"),
 
 
 @prefect.task
-def data_monitoring(config_json_path):
-    config=utils.functions.local.read_configJSON(path=config_json_path)
+def data_monitoring(config):
     return utils.monitoring.run(rules_list=config["rules"])
 
 def prefect_parameter_read_json(path,param_name):
         return prefect.Parameter(param_name,
-                                 default=utils.functions.local(path,"string")
+                                 default=utils.local.read_configJSON(path,"string")
                                  )
\ No newline at end of file
